"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const graphql_1 = require("graphql");
const _1 = require(".");
const pubSchema = (0, graphql_1.buildSchema)(`
    type TestEvent {
      id: ID!
      name: String
    }
    type Query {
      TestEvent: TestEvent!
    }
  `);
test("valid event is published", () => (0, tslib_1.__awaiter)(void 0, void 0, void 0, function* () {
    const publishCb = jest.fn();
    const bus = new _1.VanillaEventBus({
        plugins: [],
        publisher: {
            schema: pubSchema,
            publish: (d) => (0, tslib_1.__awaiter)(void 0, void 0, void 0, function* () {
                publishCb(d);
            }),
        },
    });
    yield bus.init();
    yield bus.publish({
        topicName: "TestEvent",
        data: {
            id: "123",
            name: "name",
        },
    });
    expect(publishCb).toBeCalledTimes(1);
    const errorCb = jest.fn();
    yield bus
        .publish({
        topicName: "NonExistingEvent",
        data: {
            id: "123",
            name: "name",
        },
    })
        .catch((e) => {
        errorCb();
    });
    expect(errorCb).toBeCalled();
}));
test("valid payload is published", () => (0, tslib_1.__awaiter)(void 0, void 0, void 0, function* () {
    const publishCb = jest.fn();
    const bus = new _1.VanillaEventBus({
        plugins: [],
        publisher: {
            schema: pubSchema,
            publish: (d) => (0, tslib_1.__awaiter)(void 0, void 0, void 0, function* () {
                publishCb(d);
            }),
        },
    });
    yield bus.init();
    const errorCb = jest.fn();
    yield bus
        .publish({
        topicName: "TestEvent",
        data: {
            id: "123",
        },
    })
        .catch((e) => {
        errorCb();
    });
    // name is not required
    expect(errorCb).not.toBeCalled();
    yield bus
        .publish({
        topicName: "TestEvent",
        data: {
            name: "123",
        },
    })
        .catch((e) => {
        errorCb();
    });
    // id is required
    expect(errorCb).toBeCalled();
}));
